@@ -18,7 +18,6 @@ from nordea_analytics.nalib.exceptions import CustomWarningCheck
 from nordea_analytics.nalib.util import (
     convert_to_float_if_float,
     convert_to_variable_string,
-    float_to_tenor_string,
     get_config,
 )
 from nordea_analytics.nalib.util import get_keyfigure_key
@@ -51,14 +50,15 @@ class BondKeyFigureCalculator(ValueRetriever):
                 List[Union[str, CurveName]],
             ]
         ] = None,
-        rates_shifts: Optional[Union[List[str], str]] = None,
+        shift_tenors: Union[List[float], float] = None,
+        shift_values: Union[List[float], float] = None,
         pp_speed: Optional[float] = None,
         prices: Optional[Union[float, List[float]]] = None,
         spread: Optional[float] = None,
         spread_curve: Optional[Union[str, CurveName]] = None,
         yield_input: Optional[float] = None,
         asw_fix_frequency: Optional[str] = None,
-        ladder_definition: Optional[List[str]] = None,
+        ladder_definition: Optional[List[float]] = None,
         cashflow_type: Optional[Union[str, CashflowType]] = None,
     ) -> None:
         """Initialization of class.
@@ -70,8 +70,8 @@ class BondKeyFigureCalculator(ValueRetriever):
             keyfigures: Bond key figure that should be valued.
             calc_date: date of calculation.
             curves: discount curves for calculation.
-            rates_shifts: shifts in curves("tenor shift in bbp"
-                like "0Y 5" or "30Y -5").
+            shift_tenors: Optional. Tenors to shift curves expressed as float. For example [0.25, 0.5, 1, 3, 5].
+            shift_values: Optional. Shift values in basispoints. For example [100, 100, 75, 100, 100].
             pp_speed: Prepayment speed. Default = 1.
             prices: fixed price per bond.
             spread: fixed spread for bond. Mandatory to give
@@ -81,11 +81,13 @@ class BondKeyFigureCalculator(ValueRetriever):
             yield_input: fixed yield for bond.
             asw_fix_frequency: Fixing frequency of swap in ASW calculation.
                 Mandatory input in all ASW calculations.
-            ladder_definition: What tenors should be included in BPV ladder calculation.
+            ladder_definition: Optional. Tenors should be included in
+                BPV ladder calculation. For example [0.25, 0.5, 1, 3, 5].
             cashflow_type: Type of cashflow to calculate with.
         """
         super(BondKeyFigureCalculator, self).__init__(client)
         self._client = client
+
         _keyfigures: List = keyfigures if isinstance(keyfigures, list) else [keyfigures]
         self.keyfigures = [
             convert_to_variable_string(keyfigure, CalculatedBondKeyFigureName)
@@ -93,6 +95,7 @@ class BondKeyFigureCalculator(ValueRetriever):
             else keyfigure.lower()
             for keyfigure in _keyfigures
         ]
+
         self.symbols = symbols if isinstance(symbols, list) else [symbols]
         self.calc_date = calc_date
         self.key_figures_original: Union[
@@ -127,7 +130,8 @@ class BondKeyFigureCalculator(ValueRetriever):
             _curves = None
 
         self.curves = _curves
-        self.rates_shifts = rates_shifts
+        self.shift_tenors = shift_tenors
+        self.shift_values = shift_values
         self.pp_speed = pp_speed
 
         _prices: Union[List[float], None]
@@ -167,7 +171,7 @@ class BondKeyFigureCalculator(ValueRetriever):
         json_response: Dict = {}
         for request_dict in self.request:
             try:
-                _json_response = self._client.get_post_get_response(
+                _json_response = self._client.get_response_asynchronous(
                     request_dict, self.url_suffix
                 )
                 json_response[request_dict["symbol"]] = _json_response
@@ -198,7 +202,8 @@ class BondKeyFigureCalculator(ValueRetriever):
                 "date": self.calc_date.strftime("%Y-%m-%d"),
                 "keyfigures": keyfigures,
                 "curves": self.curves,
-                "rates_shift": self.rates_shifts,
+                "shift_tenors": self.shift_tenors,
+                "shift_values": self.shift_values,
                 "pp_speed": self.pp_speed,
                 "price": self.prices[x]
                 if self.prices is not None and x < len(self.prices)
@@ -251,7 +256,7 @@ class BondKeyFigureCalculator(ValueRetriever):
                     _data_dict: Dict[Any, Any] = {}
                     if key_figure == "bpvladder":
                         ladder_dict = {
-                            float_to_tenor_string(
+                            convert_to_float_if_float(
                                 ladder["key"]
                             ): convert_to_float_if_float(ladder["value"])
                             for ladder in curve_data["ladder"]
